@@ -1,4 +1,3 @@
-context("test-dim")
 
 # vec_dim -----------------------------------------------------------------
 
@@ -9,10 +8,10 @@ test_that("dim is dimensions", {
 })
 
 
-test_that("dims is number of dimensions", {
-  expect_equal(vec_dims(array(dim = c(1))), 1)
-  expect_equal(vec_dims(array(dim = c(1, 1))), 2)
-  expect_equal(vec_dims(array(dim = c(1, 1, 1))), 3)
+test_that("dim_n is number of dimensions", {
+  expect_equal(vec_dim_n(array(dim = c(1))), 1)
+  expect_equal(vec_dim_n(array(dim = c(1, 1))), 2)
+  expect_equal(vec_dim_n(array(dim = c(1, 1, 1))), 3)
 })
 
 test_that("vector and 1-d array are equivalent", {
